List:Commits« Previous MessageNext Message »
From:msvensson Date:November 27 2007 7:50am
Subject:bk commit into 5.1 tree (msvensson:1.2645) BUG#25146
View as plain text  
Below is the list of changes that have just been committed into a local
5.1 repository of msvensson. When msvensson does a push these changes will
be propagated to the main repository and, within 24 hours after the
push, to the public repository.
For information on how to access the public repository
see http://dev.mysql.com/doc/mysql/en/installing-source-tree.html

ChangeSet@stripped, 2007-11-27 08:50:13+01:00, msvensson@stripped +1 -0
  Bug#25146 Some warnings/errors not shown when using --show-warnings
   - Additional patch to fix compiler warnings

  client/mysql.cc@stripped, 2007-11-27 08:50:11+01:00, msvensson@stripped +3 -2
    Initialize warnings to 0 to avid compiler warning
    Call 'print_warnings' also when error occured

diff -Nrup a/client/mysql.cc b/client/mysql.cc
--- a/client/mysql.cc	2007-11-21 04:35:12 +01:00
+++ b/client/mysql.cc	2007-11-27 08:50:11 +01:00
@@ -2155,7 +2155,7 @@ com_go(String *buffer,char *line __attri
 {
   char		buff[200], time_buff[32], *pos;
   MYSQL_RES	*result;
-  ulong		timer, warnings;
+  ulong		timer, warnings= 0;
   uint		error= 0;
   int           err= 0;
 
@@ -2305,7 +2305,8 @@ com_go(String *buffer,char *line __attri
 
 end:
 
-  if (show_warnings == 1 && warnings >= 1) /* Show warnings if any */
+  /* Show warnings if any or error occured */
+  if (show_warnings == 1 && (warnings >= 1 || error))
     print_warnings();
 
   if (!error && !status.batch && 
Thread
bk commit into 5.1 tree (msvensson:1.2645) BUG#25146msvensson27 Nov